OnExhaustedPolicy

Enum OnExhaustedPolicy 

pub enum OnExhaustedPolicy {
    Wait {
        timeout: Duration,
    },
    Fail,
}
Defines how to react when memory cannot be acquired immediately.

Variants



Wait

Wait until enough memory is released, bounded by timeout.

Fields

timeout: Duration


Fail

Fail immediately if memory is not available.